@@ -1,5 +1,6 @@
 #!/bin/bash
 # Copyright (c) 2020 Red Hat, Inc.
+# Copyright Contributors to the Open Cluster Management project
 
 echo $1
 
@@ -114,9 +115,9 @@ echo "=====Initial setup for tests====="
 
 	echo "Current directory"
 	echo $(pwd)
-	echo -n "Create namespace open-cluster-management: " && kubectl create namespace open-cluster-management
+	echo -n "Create namespace open-cluster-management-monitoring: " && kubectl create namespace open-cluster-management
     echo -n "Creating pull secret: " && kubectl create secret docker-registry search-operator-pull-secret --docker-server=quay.io --docker-username=$DOCKER_USER --docker-password=$DOCKER_PASS
-	# git clone https://github.com/stolostron/search-operator.git
+	# git clone https://github.com/open-cluster-management/search-operator.git
 
 	# cd search-operator
     echo -n "Applying search operator CRD:" && kubectl apply -f ./config/crd/bases/search.open-cluster-management.io_searchoperators.yaml
@@ -131,6 +132,7 @@ echo "=====Initial setup for tests====="
     echo "=====Deploying search-operator====="
 	$sed_command "s~{{ OPERATOR_IMAGE }}~$IMAGE_NAME~g" ./test/operator-deployment.yaml
 	echo -n "Applying search operator deployment: " && kubectl apply -f ./test/operator-deployment.yaml
+	echo -n "Set DEPLOY_REDISGRAPH variable: " && kubectl set env deploy search-operator DEPLOY_REDISGRAPH="true"
 	# # change the image name back to OPERATOR_IMAGE in operator deployment for next run
 	sed -i '-e' "s~$IMAGE_NAME~{{ OPERATOR_IMAGE }}~g" ./test/operator-deployment.yaml
 }
@@ -314,7 +316,7 @@ test_update_podresource_search_operator() {
 test_fallback_emptydir() {
 	echo "=====Delete searchcustomization and test fallbackto EmptyDir====="
 	echo -n "Delete searchcustomization: " && kubectl delete searchcustomization searchcustomization 
-	echo -n "Patch searchoperator: " && kubectl patch sc standard -p '{"metadata":{"annotations":{"storageclass.kubernetes.io/is-default-class":"false"}}}' --type='merge'
+	echo -n "Patch storageclass: " && kubectl patch sc standard -p '{"metadata":{"annotations":{"storageclass.kubernetes.io/is-default-class":"false"}}}' --type='merge'
 	echo -n "Scale statefulset : " && kubectl scale statefulset search-redisgraph --replicas=0
 	echo -n "Delete pvc : " && kubectl delete pvc search-redisgraph-pvc-0
 	echo -n "Delete statefulset : " && kubectl delete statefulset search-redisgraph
